# DINJO Is Not Just an Optimizer

``DINJO Is Not Just An Optimizer`` is a Python framework designed for the optimization of initial value problems' parameters.

Lets say you have some 'experimental' data of a state variable ``S`` corresponding to the initial value problem ``dS/dt = f(t, S; p), S(t_0) = f_0`` where ``p`` is a list of parameters. If you want to know the optimal value of ``p`` so that the solution of the initial value problem fits your experimental data, you can use DINJO to get an approximate value of the optimal ``p``.

**Visit [DINJO's official documentation](https://dinjo.readthedocs.io/)**
